<?php
/**
 * Footer template file.
 */
?>

        <?php
        /*
         * Theme action basho_before_footer.
         *
         * @hooked basho_footer_sidebars()
         */
        do_action( 'basho_before_footer' ); ?>

        <footer id="site-footer" role="contentinfo" class="uk-section uk-section-small">

            <div class="uk-container<?php echo esc_attr( basho_get_container_width_class( 'footer' ) ); ?>">
                <div class="uk-child-width-1-1 uk-child-width-expand@m uk-flex-middle uk-flex-center" data-uk-grid>
                    <?php
                    /*
                     * Functions hooked into basho_after_footer action.
                     *
                     * @hooked basho_print_footer_left_section()      - 0
                     * @hooked basho_print_footer_center_section()    - 10
                     * @hooked basho_print_footer_right_section()     - 20
                     */
                    do_action( 'basho_footer' ); ?>
                </div>
            </div>

        </footer> <!-- #site-footer -->

        <?php
        /*
         * Functions hooked into basho_after_footer action.
         *
         * @hooked basho_offcanvas_navigation()                       - 0
         * @hooked basho_search_modal()                               - 10
         */
        do_action( 'basho_after_footer' ); ?>

    </div><!-- #site-wrapper -->
<?php wp_footer(); ?>
</body>
</html>
